window.Gleam.initSearch([{"doc":"recursive","title":"recursive","content":"# recursive\n\n[![Package Version](https://img.shields.io/hexpm/v/recursive)](https://hex.pm/packages/recursive)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/recursive/)\n\n```sh\ngleam add recursive\n```\n\n```gleam\nimport gleam/io\nimport recursive\n\npub fn main() {\n   // Factorial\n   io.debug({\n    use it, f &lt;- recursive.use_fix(10)\n    case it {\n      0 -&gt; 1\n      _ -&gt; it * f(it - 1)\n    }\n   })\n   let fac = recursive.fix(fn (it, f) {\n      case it {\n        0 -&gt; 1\n        _ -&gt; it * f(it - 1)\n      }\n   })\n\n   // Tail recursive factorial\n   io.debug({\n    use it, res, f &lt;- recursive.use_fix2(10, 1)\n    case it {\n      0 -&gt; res\n      _ -&gt; f(it - 1, res * it)\n    }\n   })\n   let memo_fac = recursive.fix2(fn (it, res, f) {\n      case it {\n        0 -&gt; res\n        _ -&gt; f(it - 1, res * it)\n      }\n   })\n\n   // Tail recursive fibonacci\n   io.debug({\n    use it, curr, prev, f &lt;- recursive.use_fix3(9, 1, 0)\n    case it {\n      0 -&gt; curr\n      _ -&gt; f(it - 1, curr + prev, curr)\n    }\n   })\n   let fib = recursive.fix3(fn (it, curr, prev, f) {\n      case it {\n        0 -&gt; curr\n        _ -&gt; f(it - 1, curr + prev, curr)\n      }\n   })\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/recursive&gt;.\n\n## Development\n\n```sh\ngleam test\n```\n","url":"index.html"},{"doc":"recursive","title":"fix","content":"pub fn fix(cb: fn(a, fn(a) -&gt; b) -&gt; b) -&gt; fn(a) -&gt; b\n Fixed-point combinator.\n Allows anonymous functions to run recursively\n \n let factorial = recursive.fix(fn (it, f) {\n   case it {\n     0 -&gt; 1\n     1 -&gt; 1\n     _ -&gt; it * f(it - 1)\n   }\n })\n io.debug(factorial(10))\n \nSynonyms:\nrecursive.fix\nrecursive fix","url":"recursive.html#fix"},{"doc":"recursive","title":"fix2","content":"pub fn fix2(cb: fn(a, b, fn(a, b) -&gt; c) -&gt; c) -&gt; fn(a, b) -&gt; c\n Two argument Fixed-point combinator.\n Allows anonymous functions to run recursively\n \n let factorial = recursive.fix2(fn (it, res, f) {\n   case it {\n     0 -&gt; res\n     1 -&gt; res\n     _ -&gt; f(it - 1, res * it)\n   }\n })\n io.debug(factorial(10, 1))\n \nSynonyms:\nrecursive.fix2\nrecursive fix2","url":"recursive.html#fix2"},{"doc":"recursive","title":"fix3","content":"pub fn fix3(\n  cb: fn(a, b, c, fn(a, b, c) -&gt; d) -&gt; d,\n) -&gt; fn(a, b, c) -&gt; d\n Three argument Fixed-point combinator.\n Allows anonymous functions to run recursively\n \n let fibonacci = recursive.fix3(fn (it, curr, prev, f) {\n    case it {\n      0 -&gt; curr\n      _ -&gt; f(it - 1, curr + prev, curr)\n    }\n })\n io.debug(fibonacci(9, 1, 0))\n \nSynonyms:\nrecursive.fix3\nrecursive fix3","url":"recursive.html#fix3"},{"doc":"recursive","title":"fix4","content":"pub fn fix4(\n  cb: fn(a, b, c, d, fn(a, b, c, d) -&gt; e) -&gt; e,\n) -&gt; fn(a, b, c, d) -&gt; e\n Four argument Fixed-point combinator.\n Allows anonymous functions to run recursively\nSynonyms:\nrecursive.fix4\nrecursive fix4","url":"recursive.html#fix4"},{"doc":"recursive","title":"fix5","content":"pub fn fix5(\n  cb: fn(a, b, c, d, e, fn(a, b, c, d, e) -&gt; f) -&gt; f,\n) -&gt; fn(a, b, c, d, e) -&gt; f\n Five argument Fixed-point combinator.\n Allows anonymous functions to run recursively\nSynonyms:\nrecursive.fix5\nrecursive fix5","url":"recursive.html#fix5"},{"doc":"recursive","title":"rec","content":"pub fn rec(f: fn(fn() -&gt; a) -&gt; a) -&gt; a\n Raw fixed-point combinator.\n Not intended to be used standalone\nSynonyms:\nrecursive.rec\nrecursive rec","url":"recursive.html#rec"},{"doc":"recursive","title":"use_fix","content":"pub fn use_fix(initial: a, cb: fn(a, fn(a) -&gt; b) -&gt; b) -&gt; b\n Usable Fixed-point combinator.\n Allows any block to run recursively\n \n // Factorial \n io.debug({\n   use it, f &lt;- recursive.use_fix(10)\n   case it {\n     0 -&gt; 1\n     1 -&gt; 1\n     _ -&gt; it * f(it - 1)\n   }\n })\n \nSynonyms:\nrecursive.use_fix\nrecursive use_fix","url":"recursive.html#use_fix"},{"doc":"recursive","title":"use_fix2","content":"pub fn use_fix2(\n  a: a,\n  b: b,\n  cb: fn(a, b, fn(a, b) -&gt; c) -&gt; c,\n) -&gt; c\n Two argument Fixed-point combinator.\n Allows any block to run recursively\n \n // Tail recursive factorial \n io.debug({\n   use it, res, f &lt;- recursive.use_fix2(10, 1)\n   case it {\n     0 -&gt; res\n     1 -&gt; res\n     _ -&gt; f(it - 1, res * it)\n   }\n })\n \nSynonyms:\nrecursive.use_fix2\nrecursive use_fix2","url":"recursive.html#use_fix2"},{"doc":"recursive","title":"use_fix3","content":"pub fn use_fix3(\n  a: a,\n  b: b,\n  c: c,\n  cb: fn(a, b, c, fn(a, b, c) -&gt; d) -&gt; d,\n) -&gt; d\n Three argument Fixed-point combinator.\n Allows any block to run recursively\n \n // Fibonacci \n io.debug({\n   use it, curr, prev, f &lt;- recursive.use_fix3(9, 1, 0)\n   case it {\n    0 -&gt; curr\n    _ -&gt; f(it - 1, curr + prev, curr)\n   }\n })\n \nSynonyms:\nrecursive.use_fix3\nrecursive use_fix3","url":"recursive.html#use_fix3"},{"doc":"recursive","title":"use_fix4","content":"pub fn use_fix4(\n  a: a,\n  b: b,\n  c: c,\n  d: d,\n  cb: fn(a, b, c, d, fn(a, b, c, d) -&gt; e) -&gt; e,\n) -&gt; e\n Four argument Fixed-point combinator.\n Allows any block to run recursively\nSynonyms:\nrecursive.use_fix4\nrecursive use_fix4","url":"recursive.html#use_fix4"},{"doc":"recursive","title":"use_fix5","content":"pub fn use_fix5(\n  a: a,\n  b: b,\n  c: c,\n  d: d,\n  e: e,\n  cb: fn(a, b, c, d, e, fn(a, b, c, d, e) -&gt; f) -&gt; f,\n) -&gt; f\n Five argument Fixed-point combinator.\n Allows any block to run recursively\nSynonyms:\nrecursive.use_fix5\nrecursive use_fix5","url":"recursive.html#use_fix5"},{"doc":"recursive","title":"recursive","content":"","url":"recursive.html"}]);